A seek point in the seek table.
Fields
sample: u64Sample number of the first sample in the target frame, or 264 - 1 for a placeholder.
offset: u64Offset in bytes from the first byte of the first frame header to the first byte of the target frame’s header.
samples: u16Number of samples in the target frame.