pub struct VorbisComment {
    pub vendor: String,
    pub comments: Vec<(String, usize)>,
}
Vorbis comments, also known as FLAC tags (e.g. artist, title, etc.).

Fields

vendor: String

The “vendor string”, chosen by the encoder vendor.

This string usually contains the name and version of the program that encoded the FLAC stream, such as reference libFLAC 1.3.2 20170101 or Lavf57.25.100.

comments: Vec<(String, usize)>

Name-value pairs of Vorbis comments, such as ARTIST=Queen.

This struct stores a raw low-level representation of tags. Use FlacReader::tags() for a friendlier iterator. The tuple consists of the string in "NAME=value" format, and the index of the '=' into that string.

The name is supposed to be interpreted case-insensitively, and is guaranteed to consist of ASCII characters. Claxon does not normalize the casing of the name. Use metadata::GetTag to do a case-insensitive lookup.

Names need not be unique. For instance, multiple ARTIST comments might be present on a collaboration track.

See https://www.xiph.org/vorbis/doc/v-comment.html for more details.